from fedoidcmsg.entity import make_federation_entity
from oidcrp import oidc


class RP(oidc.RP):
    def __init__(self, state_db, ca_certs=None, client_authn_factory=None,
                 keyjar=None, verify_ssl=True, config=None, client_cert=None,
                 httplib=None, services=None, service_factory=None):
        oidc.RP.__init__(self, state_db, ca_certs,
                         client_authn_factory=client_authn_factory,
                         keyjar=keyjar, verify_ssl=verify_ssl,
                         config=config, client_cert=client_cert,
                         httplib=httplib, services=services,
                         service_factory=service_factory)

        fe = make_federation_entity(config['federation'], '', self.http,
                                    verify_ssl=verify_ssl)
        self.service_context.federation_entity = fe



#!/usr/bin/env python
#
# Copyright (C) 2017 Roland Hedberg, Sweden
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import re
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

__author__ = 'Roland Hedberg'


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest

        errno = pytest.main(self.test_args)
        sys.exit(errno)


with open('src/fedoidcrp/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

setup(
    name="fedoidcrp",
    version=version,
    description="Python implementation of a federation aware OpenID Connect RP",
    author="Roland Hedberg",
    author_email="roland@catalogix.se",
    license="Apache 2.0",
    url='https://github.com/IdentityPython/fedoidcmsg/',
    packages=["fedoidcrp", "fedoidcrp/oidc"],
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Topic :: Software Development :: Libraries :: Python Modules"],
    install_requires=[
        'fedoidcmsg',
        'fedoidcservice',
        'oidcop',
        'cryptojwt',
        'oidcservice',
    ],
    tests_require = [
        'pytest',
        'pytest-localserver',
    ],
    zip_safe=False,
    cmdclass={'test': PyTest},
)
